@@ -3,8 +3,8 @@
 # Makefile for Java API Compliance Checker
 # Install/remove the tool for GNU/Linux, FreeBSD and Mac OS X
 #
-# Copyright (C) 2011 Russian Linux Verification Center
-# Copyright (C) 2011-2014 ROSA Laboratory
+# Copyright (C) 2011 Institute for System Programming, RAS
+# Copyright (C) 2011-2015 Andrey Ponomarenko's ABI Laboratory
 #
 # Written by Andrey Ponomarenko
 #
@@ -44,7 +44,6 @@ DESCRIPTION:
 
 USAGE:
   sudo perl $0 -install -prefix /usr
-  sudo perl $0 -update -prefix /usr
   sudo perl $0 -remove -prefix /usr
 
 OPTIONS:
@@ -52,14 +51,11 @@ OPTIONS:
       Print this help.
 
   --prefix=PREFIX
-      Install files in PREFIX [/usr/local].
+      Install files in PREFIX [/usr].
 
   -install
       Command to install the tool.
 
-  -update
-      Command to update existing installation.
-
   -remove
       Command to remove the tool.
 
@@ -77,14 +73,13 @@ if(not @ARGV)
     exit(0);
 }
 
-my ($PREFIX, $DESTDIR, $Help, $Install, $Update, $Remove);
+my ($PREFIX, $DESTDIR, $Help, $Install, $Remove);
 
 GetOptions(
     "h|help!" => \$Help,
     "prefix=s" => \$PREFIX,
     "destdir=s" => \$DESTDIR,
     "install!" => \$Install,
-    "update!" => \$Update,
     "remove!" => \$Remove
 ) or exit(1);
 
@@ -95,18 +90,24 @@ sub scenario()
         print $HELP_MSG;
         exit(0);
     }
-    if(not $Install and not $Update and not $Remove)
+    if(not $Install and not $Remove)
     {
-        print STDERR "ERROR: command is not selected (-install, -update or -remove)\n";
+        print STDERR "ERROR: command is not selected (-install or -remove)\n";
         exit(1);
     }
+    
+    if($Install)
+    { # remove old version first
+        $Remove = 1;
+    }
+    
     if($PREFIX ne "/") {
         $PREFIX=~s/[\/]+\Z//g;
     }
     if(not $PREFIX)
     { # default prefix
         if($Config{"osname"}!~/win/i) {
-            $PREFIX = "/usr/local";
+            $PREFIX = "/usr";
         }
     }
     if(my $Var = $ENV{"DESTDIR"})
@@ -163,31 +164,28 @@ sub scenario()
         print STDERR "ERROR: you should be root\n";
         exit(1);
     }
-    if($Remove or $Update)
+    if($Remove)
     {
         if(-e $EXE_PATH."/".$TOOL_SNAME)
         { # remove executable
             print "-- Removing $TOOL_PATH\n";
             unlink($EXE_PATH."/".$TOOL_SNAME);
         }
+        elsif(not $Install) {
+            print "The tool is not installed\n";
+        }
         
         if(-d $MODULES_PATH)
         { # remove modules
             print "-- Removing $MODULES_PATH\n";
             rmtree($MODULES_PATH);
         }
-    }
-    if($Install or $Update)
-    {
-        if(-e $EXE_PATH."/".$TOOL_SNAME or -e $MODULES_PATH)
-        { # check installed
-            if(not $Remove)
-            {
-                print STDERR "ERROR: you should remove old version first (`perl $0 -remove --prefix=$PREFIX`)\n";
-                exit(1);
-            }
+        elsif(not $Install) {
+            print "The modules of the tool are not installed\n";
         }
-        
+    }
+    if($Install)
+    {
         # configure
         my $Content = readFile($ARCHIVE_DIR."/".$TOOL_SNAME.".pl");
         if($DESTDIR) { # relative path
@@ -201,7 +199,7 @@ sub scenario()
         print "-- Installing $TOOL_PATH\n";
         mkpath($EXE_PATH);
         writeFile($EXE_PATH."/".$TOOL_SNAME, $Content);
-        chmod(0775, $EXE_PATH."/".$TOOL_SNAME);
+        chmod(0755, $EXE_PATH."/".$TOOL_SNAME);
         
         if($Config{"osname"}=~/win/i) {
             writeFile($EXE_PATH."/".$TOOL_SNAME.".cmd", "\@perl \"$TOOL_PATH\" \%*");
